@@ -61,6 +61,7 @@ As a module:
 __version__ = "0.2.3"
 
 from jjcli import *
+import os
 from unidecode import unidecode
 import json
 import yaml
@@ -184,7 +185,10 @@ def mexpandpp():       # main for owlexpand
    g.pprint()
 
 def mxdxf():           # main for owlxdxf
-   c=clfilter(opt="no:s:t")
+   c=clfilter(opt="b:no:s:t")
+   if "-b" not in c.opt:
+       basedir = os.path.dirname(os.path.realpath(c.args[0]))
+       c.opt["-b"]=basedir
    g=owlproc(c.args,c.opt)
    g.xdxf()
 
@@ -386,8 +390,12 @@ class owlproc:
           if ppstr in {':img','IMG',':jpg',':png'}:
               print(f"   <def><img width='500px' src={opstr}/></def>",
                     file=f)
-          elif ppstr in {':pdf',':url'}:
-              print(f"   <def><iref href={opstr}>{pstr} ↗</iref></def>",
+          elif ppstr in {':pdf',':url',':midi'}:
+              if "-b" in self.opt:
+                  aux = opstr.strip('"')
+                  basedir = self.opt["-b"]
+                  url = f'"file:///{basedir}/{aux}"'
+              print(f"   <def><iref href={url}>{pstr} ↗</iref></def>",
                     file=f)
           elif islit(o):
               print(f"   <def>{pstr}: {ostr}</def>",
